@@ -1,5 +1,5 @@
 /*
- * Copyright (C) Jan 2019 Mellanox Technologies Ltd. All rights reserved.
+ * Copyright (c) 2019-2021 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
  *
  * This software is available to you under a choice of one of two
  * licenses.  You may choose to be licensed under the terms of the GNU
@@ -40,18 +40,18 @@
 #include <stdint.h>
 #include <mlxreg/mlxreg_lib.h>
 #include <mlxreg/mlxreg_parser.h>
+#include "mlxlink_enums.h"
 
 using namespace std;
 
-class UserInput {
+class UserInput
+{
 public:
     UserInput();
-    virtual ~UserInput()
-    {
-    }
-    ;
+    virtual ~UserInput(){};
     u_int32_t _labelPort;
     u_int32_t _splitPort;
+    u_int32_t _secondSplitPort;
     u_int32_t _depth;
     u_int32_t _pcieIndex;
     u_int32_t _node;
@@ -73,8 +73,11 @@ public:
     bool _sendDpn;
     bool _db;
     bool _sltpLane;
+    bool _txPolicy;
     bool _advancedMode;
-    bool _specifiedPort;
+    bool _portSpecified;
+    bool _splitProvided;
+    bool _secondSplitProvided;
     bool _showSltp;
     bool _showSlrp;
     bool _showCounters;
@@ -128,11 +131,28 @@ public:
     int mixerOffset1;
     bool showMixers;
 
-    string eomMeasurementStr;
-
     bool enableFecHistogram;
     bool showFecHistogram;
     bool clearFecHistogram;
+
+    map<ModulePrbs_t, string> modulePrbsParams;
+    bool isPrbsSelProvided;
+    bool isPrbsModeProvided;
+    bool isPrbsChProvided;
+    bool isPrbsGenProvided;
+    bool isPrbsShowDiagProvided;
+    bool isPrbsClearDiagProvided;
+    ModuleAccess_t prbsModuleAccess;
+
+    bool isModuleConfigParamsProvided;
+    vector<pair<ControlParam, string>> configParamsToSet;
+
+    bool isPcieErrInjProvided;
+    string errorType;
+    int errorDuration;
+    int injDelay;
+    string dbdf;
+    vector<string> parameters;
 };
 
 #endif /* MLXLINK_USER_INPUT_H */
